#include <iostream>
using std::cout;
using std::cerr;
using std::endl;

#include <iomanip>
using std::setw;

#include "particle.hpp"
#include "ode_solver.h"

// acceleration model:

double gravity(const particle &p)
{
	return -9.80665; // m/s^2
}

int main()
{
	const double duration = 100.0; // run simulation for 100 s
	const unsigned int steps = 100;
	const double dt = duration / steps;
	cerr << "Simulating freefall with time step dt = " << dt << endl;

	// p is a particle of mass 1 kg at rest at a height of 50 km :
	particle p(1.0,50000.0,0.0); 

	for (unsigned int n = 0; n < steps; ++n)
	{
		cout << p << endl; // output the particle information in (t,x,v) format
		p.evolve(gravity,Verlet,dt); // perform a single Euler update for a particle in free-fall
	}
	cout << p << endl;
}