#ifndef PARTICLE_HPP
#define PARTICLE_HPP

#include <iostream>
using std::ostream;

#include <iomanip>
using std::setw;

class particle
{
public:
	// member data
	double mass;
	double x; // position
	double v; // velocity
	double t; // current time;

	// constructor
	particle(double m_, double x_, double v_) : mass(m_), x(x_), v(v_), t(0) {}
	
	// methods (or member functions)
	void evolve( double (&accel)(const particle&), void (&method)(particle&,double,double), double dt)
	{
		// *this refers to the active particle object
		method( *this, accel(*this), dt );
	}

	void evolve( double (&accel)(const particle&), void (&method)(particle&,double (&)(const particle&),double), double dt)
	{
		// *this refers to the active particle object
		method( *this, accel, dt );
	}

	// a friend function does not belong to the class but is affiliated with it
	friend ostream& operator<<(ostream& os, const particle &p)
	{
		os.precision(8);
		os << setw(20) << p.t
		    << setw(20) << p.x
		   << setw(20) << p.v;
		return os;
	}
};

#endif // PARTICLE_HPP
